<?php

namespace App\Exports;
  
use App\User;
use Maatwebsite\Excel\Concerns\FromCollection;
use Maatwebsite\Excel\Concerns\Exportable;
use Maatwebsite\Excel\Concerns\WithMapping;
use Maatwebsite\Excel\Concerns\WithHeadings;
use Maatwebsite\Excel\Concerns\ShouldAutoSize;
use Maatwebsite\Excel\Concerns\WithEvents;
use Maatwebsite\Excel\Events\AfterSheet;
use Maatwebsite\Excel\Events\BeforeExport;

  
class TransactionHistoryExport implements FromCollection, WithMapping, WithHeadings,ShouldAutoSize,WithEvents
{
	use Exportable;

    /**
    * @return \Illuminate\Support\Collection
    */
    function __construct($user_ids,$setting_data)
	{
        $this->user_ids = $user_ids;
        $this->setting_data = $setting_data;

	}

    public function collection()
    {
        if($this->user_ids)
        {
            $user_ids = explode(',', $this->user_ids);
            return User::join('vcard_member_selected_theme','vcard_member_selected_theme.user_id','=','users.id')
                ->leftjoin('vcard_member_transaction','vcard_member_transaction.user_id','=','users.id')
                ->select('users.id','users.name','users.email','users.phone','vcard_member_selected_theme.payment_status','vcard_member_transaction.name as transaction_mode','vcard_member_transaction.amount','vcard_member_transaction.created_at')
                ->whereIn('users.id',$user_ids)
                ->get();
        }
        else
        {
            return User::join('vcard_member_selected_theme','vcard_member_selected_theme.user_id','=','users.id')
                    ->leftjoin('vcard_member_transaction','vcard_member_transaction.user_id','=','users.id')
                    ->select('users.id','users.name','users.email','users.phone','vcard_member_selected_theme.payment_status','vcard_member_transaction.name as transaction_mode','vcard_member_transaction.amount','vcard_member_transaction.created_at')->get();
        }
    }

    public function map($transaction_history): array
    { 
        if($transaction_history->payment_status == '0')
        {
            $transaction_status =  'Pending';
        }
        elseif ($transaction_history->payment_status == '1') 
        {
            $transaction_status =  'Done';
        }
        else
        {
            $transaction_status =  'N/A';
        }

        if($transaction_history->transaction_mode)
        {
            $transaction_mode = $transaction_history->transaction_mode;
        }
        else
        {
            $transaction_mode = 'N/A';
        }

        if($transaction_history->amount)
        {
            $amount =  $transaction_history->amount;
        }
        else
        {
            $amount =  'N/A';
        }

        if($transaction_history->created_at)
        {
            $transaction_date =  date('d-m-Y',strtotime($transaction_history->created_at));
        }
        else
        {
            $transaction_date =  'N/A';
        }

        return [    
                    $transaction_history->name,
                    $transaction_history->email,
                    $transaction_history->phone,
                    $transaction_status,
                    $transaction_mode,
                    $amount,
                    $transaction_date
               ];
    }    

    public function headings(): array
    {
        return [
            'Name',
            'Email',
            'Phone No',
            'Payment Status',
            'Transaction Mode',
            'Transaction Amount',
            'Transaction Date'
        ];
    }
    public function registerEvents(): array
    {
        return 
        [
            AfterSheet::class => function(AfterSheet $event) {
                $event->sheet->getStyle('A1:G1')->applyFromArray([
                    'font' => [
                        'bold' => true
                    ]
                ]);
                $event->sheet->getStyle('A1:J1')->applyFromArray([
                    'alignment' => array(
                        'horizontal' => \PhpOffice\PhpSpreadsheet\Style\Alignment::HORIZONTAL_LEFT,
                    )
                ]);
            },
        ];
    }
}
