<?php

namespace App\Exports;
  
use App\User;
use Maatwebsite\Excel\Concerns\FromCollection;
use Maatwebsite\Excel\Concerns\Exportable;
use Maatwebsite\Excel\Concerns\WithMapping;
use Maatwebsite\Excel\Concerns\WithHeadings;
use Maatwebsite\Excel\Concerns\ShouldAutoSize;
use Maatwebsite\Excel\Concerns\WithEvents;
use Maatwebsite\Excel\Events\AfterSheet;
use Maatwebsite\Excel\Events\BeforeExport;

  
class VcardUsersExport implements FromCollection, WithMapping, WithHeadings,ShouldAutoSize,WithEvents
{
	use Exportable;

    /**
    * @return \Illuminate\Support\Collection
    */
    function __construct($user_ids,$setting_data)
	{
        $this->user_ids = $user_ids;
        $this->setting_data = $setting_data;

	}

    public function collection()
    {
        if($this->user_ids)
        {
            $user_ids = explode(',', $this->user_ids);
            return User::join('vcard_member_selected_theme','vcard_member_selected_theme.user_id','=','users.id')
            ->select('users.id','users.name','users.email','users.phone','vcard_member_selected_theme.created_at as vcard_created_at','vcard_member_selected_theme.payment_status','vcard_member_selected_theme.vcard_url_id','users.created_at','vcard_member_selected_theme.payment_status as trial_period')
            ->whereIn('users.id',$user_ids)
            ->get();
        }
        else
        {
        	return User::join('vcard_member_selected_theme','vcard_member_selected_theme.user_id','=','users.id')
                ->select('users.id','users.name','users.email','users.phone','vcard_member_selected_theme.created_at as vcard_created_at','vcard_member_selected_theme.payment_status','vcard_member_selected_theme.vcard_url_id','users.created_at','vcard_member_selected_theme.payment_status as trial_period')
                ->get();   
        }
    }

    public function map($vcard_user): array
    { 
        if($vcard_user->trial_period == 0)
        {
            $user_type = 'Trial user';
        }
        else
        {
            $user_type = 'Paid user';
        }

        $current_date = date('Y-m-d');
        $diff = abs(strtotime($vcard_user->created_at) - strtotime($current_date));
        // dd($diff);
        $years = (int)floor($diff / (365*60*60*24));
        $months = (int)floor(($diff - $years * 365*60*60*24) / (30*60*60*24));  
        $days = (int)floor(($diff - $years * 365*60*60*24 - $months*30*60*60*24)/ (60*60*24));
        $remaining_days = $this->setting_data[19]['value'] - $days;
        if($vcard_user->payment_status == 0 && $remaining_days > 0 )
        {
            $days_left = $remaining_days.' days';
        }
        elseif($vcard_user->payment_status == 0 && $remaining_days <= 0)
        {
            $days_left = 'Trial Period Over';
        }
        else
        {
            $days_left =  'N/A';
        }

        // $vcard_url = '<a href="'.url('share'.'/'.$vcard_user->vcard_url_id).'" target="_blank"> View Vcard</a>';
        return [    
                    $vcard_user->name,
                    $vcard_user->email,
                    $vcard_user->phone,
                    date('Y-m-d',strtotime($vcard_user->vcard_created_at)),
                    $user_type,
                    $days_left,
                    'View Card'
               ];
    }    

    public function headings(): array
    {
        return [
            'Name',
            'Email',
            'Phone No',
            'Vcard Created at',
            'User Type',
            'Days Left For Trial Period',
            'Vcard Url'
        ];
    }
    public function registerEvents(): array
    {
        $vcard_url_array = User::join('vcard_member_selected_theme','vcard_member_selected_theme.user_id','=','users.id')
            ->select('vcard_member_selected_theme.vcard_url_id')
            ->get()->toArray();
            // dd($vcard_url_array);

        return 
        [
            AfterSheet::class => function(AfterSheet $event)  use($vcard_url_array) {
                $event->sheet->getStyle('A1:G1')->applyFromArray([
                    'font' => [
                        'bold' => true
                    ]
                ]);
                foreach ($vcard_url_array as $key => $value) 
                {
                    $cell_row_no = $key+2;
                    $event->sheet->getCell('G'.$cell_row_no)->getHyperlink()->setUrl(url('share'.'/'.$value['vcard_url_id']));
                }

            },
        ];
    }
}
