<?php

namespace App\Http\Controllers\New_site\Admin;

use App\ResellerModels\Coupon;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use DataTables;
use App\ResellerModels\Admin;
use App\ResellerModels\User;
use App\Seller;
use App\ResellerModels\Setting;
use App\ResellerModels\VCardSelectedTheme;
use App\ResellerModels\Plan;
use App\Http\Requests\Admin\SettingValidation;
use Auth;
use App\Exports\RegisteredUsersExport;
use App\Exports\VcardUsersExport;
use App\Exports\TransactionHistoryExport;
use Maatwebsite\Excel\Facades\Excel;
use Illuminate\Support\Facades\Mail;
use App\Mail\AdminMail;

class DashboardController extends Controller
{
    public function __construct()
    {
        $this->setting_data = Setting::get()->toArray();
    }

    public function index()
    {
        $setting_data = $this->setting_data;
        $counter =
        [
            'registered_users' =>User::count(),
            'vcard_users' =>VCardSelectedTheme::count(),
            'total_transactions' =>VCardSelectedTheme::count(),
        ];
    	return view('reseller_new_site.admin.dashboard',compact('counter','setting_data'));
        }

    
   

    public function listing(Request $request){
        $setting_data = $this->setting_data;
        if($request->type == 'registered-users')
        {
            $data = User::get();
        }elseif($request->type == 'coupon'){
            $data = Coupon::select('coupon_id','coupon_code','no_of_use','expire_date','price_discount','status','created_at')->orderby('created_at','DESC')->get();
            if ($request->ajax())
            {
                return Datatables::of($data)
                    ->addIndexColumn()
                    ->editColumn('coupon_id', function ($row) {
                        if($row->coupon_id )
                        {
                            return $row->coupon_id ;
                        }
                        else
                        {        return 'N/A';
                        }
                    })
                    ->editColumn('coupon_code', function ($row) {
                        if($row->coupon_code)
                        {
                            return $row->coupon_code;
                        }
                        else
                        {
                            return 'N/A';
                        }
                    })
                    ->editColumn('no_of_use', function ($row) {
                        if($row->no_of_use)
                        {
                            return $row->no_of_use;
                        }
                        else
                        {
                            return 'N/A';
                        }
                    })
                    ->editColumn('expire_date', function ($row) {
                        if($row->expire_date)
                        {
                            return date('d-m-Y',strtotime($row->expire_date));
                        }
                        else
                        {
                            return 'N/A';
                        }
                    })
                    ->editColumn('price_discount', function ($row) {
                        if($row->price_discount)
                        {
                            return $row->price_discount;
                        }
                        else
                        {
                            return 'N/A';
                        }
                    })
                    ->editColumn('status', function ($row) {
                        if($row->status =='1')
                        {
                            return "Active";
                        }
                        else
                        {
                            return "Inactive";
                        }
                    })
                    ->editColumn('created_at', function ($row) {
                        if($row->created_at)
                        {
                            return $row->created_at;
                        }
                        else
                        {
                            return 'N/A';
                        }
                    })
                    ->make(true);
            }
        }
        elseif($request->type == 'vcard-users')
        {
            $data = User::join('vcard_member_selected_theme','vcard_member_selected_theme.user_id','=','users.id')
            ->select('users.id','users.name','users.email','users.phone','vcard_member_selected_theme.created_at as vcard_created_at','vcard_member_selected_theme.payment_status','vcard_member_selected_theme.vcard_url_id','users.created_at','vcard_member_selected_theme.payment_status as trial_period')
            ->get();
            if ($request->ajax())
            {
                return Datatables::of($data)
                ->addIndexColumn()
                // ->rawColumns(['action'])
                ->editColumn('vcard_created_at', function ($row) {
                    return date('d-m-Y',strtotime($row->vcard_created_at));
                })
                ->editColumn('trial_period', function ($row) use($setting_data) {
                    $current_date = date('Y-m-d');
                    $diff = abs(strtotime($row->created_at) - strtotime($current_date));
                    // dd($diff);
                    $years = (int)floor($diff / (365*60*60*24));
                    $months = (int)floor(($diff - $years * 365*60*60*24) / (30*60*60*24));
                    $days = (int)floor(($diff - $years * 365*60*60*24 - $months*30*60*60*24)/ (60*60*24));
                    $remaining_days = $setting_data[19]['value'] - $days;
                    if($row->payment_status == 0 && $remaining_days > 0 )
                    {
                        return $remaining_days.' days';
                    }
                    elseif($row->payment_status == 0 && $remaining_days <= 0)
                    {
                        return 'Trial Period Over';
                    }
                    else
                    {
                        return 'N/A';
                    }
                })
                ->editColumn('payment_status', function ($row) {
                    if($row->trial_period == 0)
                    {
                        return 'Trial user';
                    }
                    else
                    {
                        return 'Paid user';
                    }
                })
                ->addColumn('vcard_url', function ($row) {
                    return '<a href="'.url('share'.'/'.$row->vcard_url_id).'" target="_blank"> View Vcard</a>';
                })
                ->rawColumns(['vcard_url'])
                ->make(true);
            }
        }
        else
        {
           $data = User::join('vcard_member_selected_theme','vcard_member_selected_theme.user_id','=','users.id')
                        ->leftjoin('vcard_member_transaction','vcard_member_transaction.user_id','=','users.id')->select('users.id','users.name','users.email','users.phone','vcard_member_selected_theme.payment_status','vcard_member_transaction.name as transaction_mode','vcard_member_transaction.amount','vcard_member_transaction.created_at')
            ->get();
            if ($request->ajax())
            {
                return Datatables::of($data)
                ->addIndexColumn()
                // ->rawColumns(['action'])
                ->editColumn('payment_status', function ($row) {
                    if($row->payment_status == '0')
                    {
                        return 'Pending';
                    }
                    elseif ($row->payment_status == '1')
                    {
                       return 'Done';
                    }
                    else
                    {
                       return 'N/A';

                    }
                    })
                ->editColumn('transaction_mode', function ($row) {
                    if($row->transaction_mode)
                    {
                        return $row->transaction_mode;
                    }
                    else
                    {
                       return 'N/A';
                    }
                    })
                ->editColumn('amount', function ($row) {
                    if($row->amount)
                    {
                        return $row->amount;
                    }
                    else
                    {
                       return 'N/A';
                    }
                    })
                ->editColumn('created_at', function ($row) {
                    if($row->created_at)
                    {
                        return date('d-m-Y',strtotime($row->created_at));
                    }
                    else
                    {
                       return 'N/A';
                    }
                    })
                ->make(true);
            }
        }

        if ($request->ajax()) {
        return Datatables::of($data)
        ->addIndexColumn()
        ->editColumn('created_at', function ($row) {
                    return date('d-m-Y',strtotime($row->created_at));
                })
        ->make(true);
        }
    }


    public function setting($type)
    {
        $setting_data = $this->setting_data;
        $setting_data = Setting::get()->toArray();
        return view('reseller_new_site.admin.'.$type.'-setting',compact('setting_data','setting_data'));
    }


    public function saveSetting(SettingValidation $request)
    {

        if ($request->setting_section == "website")
        {
            $destination_path_logo = public_path('site-logo');
            $destination_path_favicon = public_path('site-favicon');

            if(isset($request->site_logo))
            {
                $setting_site_logo = Setting::where('key','site_logo')->first();
                $site_logo = request()->file('site_logo');
                $site_logo_name = time().'.'.$site_logo->getClientOriginalExtension();
                $site_logo->move($destination_path_logo, $site_logo_name);
                $setting_site_logo->value = $site_logo_name;
                $setting_site_logo->save();
            }
            if(isset($request->site_favicon))
            {
                $setting_site_favicon = Setting::where('key','site_favicon')->first();
                $site_favicon = request()->file('site_favicon');
                $site_favicon_name = time().'.'.$site_favicon->getClientOriginalExtension();
                $site_favicon->move($destination_path_favicon, $site_favicon_name);
                $setting_site_favicon->value = $site_favicon_name;
                $setting_site_favicon->save();
            }

            foreach ($request->all() as $key => $value)
            {
               $setting = Setting::where('key',$key)->first();
               if($setting && $key != 'site_logo' && $key != 'site_favicon' )
               {
                   $setting->value = $value;
                   $setting->save();
               }
            }
            return redirect('admin/setting/website/1')->with('status','Setting updated successfully!!');
        }
        elseif ($request->setting_section == "contact")
        {
            foreach ($request->all() as $key => $value)
            {
               $setting = Setting::where('key',$key)->first();
               if($setting)
               {
                   $setting->value = $value;
                   $setting->save();
               }
            }
            return redirect('admin/setting/contact/1')->with('status','Setting updated successfully!!');
        }
        elseif ($request->setting_section == "about-us")
        {
            foreach ($request->all() as $key => $value)
            {
               $setting = Setting::where('key',$key)->first();
               if($setting)
               {
                   $setting->value = $value;
                   $setting->save();
               }
            }
            return redirect('admin/setting/about-us/1')->with('status','Setting updated successfully!!');
        }
    }


    public function savePaymentSetting(Request $request)
    {
        if($request->setting_section == "payment")
        {
            foreach ($request->all() as $key => $value)
            {
               $setting = Setting::where('key',$key)->first();
               if($setting)
               {
                   $setting->value = $value;
                   $setting->save();
               }
            }
            return response()->json([
            'message'=>'Payment Credentials updated successfully!!',
            'status'=> true
            ]);
        }
    }

    
    public function export(Request $request, $type)
    {
        if($type == 'registered-users')
        {
            return Excel::download(new RegisteredUsersExport($type,$request->user_ids), 'registered_users.xlsx');
        }
        elseif($type == 'vcard-users')
        {
            return Excel::download(new VcardUsersExport($request->user_ids,$this->setting_data), 'vcard_users.xlsx');
        }
        else
        {
            return Excel::download(new TransactionHistoryExport($request->user_ids,$this->setting_data), 'transaction_history.xlsx');
        }

    }

    public function sendMail(Request $request)
    {
        if($request->all())
        {
            Mail::to($request->user_emails)->send(new AdminMail($request->all()));
        }
        if(count(Mail::failures()) > 0)
        {
            return response()->json([
            'message'=>'Someting went wrong',
            'status'=> false
            ]);
        }
        else
        {
             return response()->json([
            'message'=>'Mail send successfully',
            'status'=> true
            ]);
        }
    }

    public function sendSMS(Request $request)
    {
        if($request->all())
        {
            dd($request->user_mobile_nos);
        }
    }

    public function updatePaymentMethod(Request $request)
    {
        $setting = Setting::where('key','payment_method')->first();
        $setting->value = $request->payment_method;
        $setting->save();
        return response()->json([
            'message'=>'Payment method updated successfully!!',
            'status'=> true
            ]);
    }
    
    public function show_plan()
    {
        $setting_data = Setting::get()->toArray();
        $plan_data=Plan::where('user_type','User')->get();
        return view('reseller_new_site.admin.show_plan')->with(['setting_data'=>$setting_data, 'plan_data'=>$plan_data]);
    }

}
