<?php
namespace App\Http\Controllers;
use App\Mail\PaymentMail;
use App\Mail\VcardMail;
use App\Models\Coupon;
use Illuminate\Http\Request;
use App\Mail\WelcomeMail;
use Illuminate\Support\Facades\Mail;
use DB;
use App\User;
use App\Models\VCardAbout;
use App\Models\VCardComDetail;
use App\Models\VCardContactDetail;
use App\Models\VCardSocialLink;
use App\Models\VCardTheme;
use App\Models\VCardSelectedTheme;
use Auth;
use PaytmWallet;
use App\Models\VCardTransaction;
use App\Models\Setting;
use Session;
use PDF;
use Instamojo;
use Illuminate\Support\Facades\Validator;
use JeroenDesloovere\VCard\VCard;
use Srmklive\PayPal\Services\ExpressCheckout;
class ProfileController extends Controller
{

    public function storeData(Request $request)
    {
        $validator = Validator::make($request->all(),[
            'fb_url' => 'nullable|regex:/^(https?:\/\/)?([\da-z\.-]+)\.([a-z\.]{2,6})([\/\w \.-]*)*\/?$/',
            'comp_yt_link' => 'nullable|regex:/^(https?:\/\/)?([\da-z\.-]+)\.([a-z\.]{2,6})([\/\w \.-]*)*\/?$/',
            'address_map_link' => 'nullable|regex:/^(https?:\/\/)?([\da-z\.-]+)\.([a-z\.]{2,6})([\/\w \.-]*)*\/?$/',
            'firstname' =>'required',
            'lastname'=>'required',
            'profession'=>'required',
            'profile_img'=>'required',
            // 'company_logo'=>'required',
        ],[
            'fname.required'=>'First Name Field is required!',
            'lastname.required'=>'Last Name Field is required!',
            'profession.required'=>'Profession  Field is required!',
            'profile_img.required'=>'Profile image Field is required!',
            'company_logo.required'=>'Company logo Field is required!',

        ]);

         if ($validator->fails()) {
             return redirect()->back()
                 ->withErrors($validator)
                 ->withInput();
         }

         $checkNotExistVcard = VCardSelectedTheme::where('user_id',Auth::user()->id)->count();
            if($checkNotExistVcard>0){
                return redirect('home')
                    ->with('danger', 'Your Vcard already exist');
            }


         $about = new VCardAbout;
         $about->fname = $request->firstname;
         $about->lname = $request->lastname;
         $about->profession = $request->profession;
         $about->about_me = $request->about_me;
         $about->user_id = Auth::user()->id;

         $contact = new VCardContactDetail();
         $contact->phone_no = $request->phone;
         $contact->email = $request->email;
         $contact->whatsapp = $request->whatsapp;
         $contact->address = $request->address;
         $contact->skype_id = $request->skype_id;
         $contact->fb_messenger_id = $request->fb_url;
         $contact->user_id = Auth::user()->id;
         $contact->save();

         $company = new VCardComDetail();
         $company->com_name = $request->company_name;
         $company->com_tagline = $request->company_title;
         $company->about_com = $request->about_company;
         $company->com_youtube_link = $request->comp_yt_link;
         $company->com_map_link = $request->address_map_link;
         $company->user_id = Auth::user()->id;
         $social = new VCardSocialLink();
         $social->social_link_name = json_encode($request->siteSocial);
         $social->social_link = json_encode(array_combine($request->siteSocial,$request->social_link));
         $social->user_id = Auth::user()->id;
         $social->save();

        if ($request->hasFile('company_logo'))
        {
            $fileLogo = "logo" . time() . '.' . request()->company_logo->getClientOriginalExtension();
            $request->company_logo->move(public_path().'/users/companylogo', $fileLogo);
            $company->com_logo = $fileLogo;
            $company->save();
        }

        if($request->hasFile('profile_img'))
        {
            $fileName = "profileImg-" . time() . '.' . request()->profile_img->getClientOriginalExtension();
            $request->profile_img->move(public_path().'/users/profileimg/', $fileName);
            $about->profile_img = $fileName;
            $about->save();
            return redirect('create-vcard/theme')
                ->with('success', 'Your Profile Data successfully Save!');
        }
    }

    public function downloadVCard($user_id)
    {
     $about = VCardAbout::where('user_id',$user_id)->orderBy('created_at', 'DESC')->first();
     $contact = VCardContactDetail::where('user_id',$user_id)->orderBy('created_at', 'DESC')->first();
     $company = VCardComDetail::where('user_id',$user_id)->orderBy('created_at', 'DESC')->first();
     $vcard = new VCard();

    // define variables

     $additional = '';
     $prefix = '';
     $suffix = '';

    // add personal data
     $vcard->addName($about->lname, $about->fname, $additional, $prefix, $suffix);

    // add work data
     if(isset($company->com_name))
     {
        $vcard->addCompany($company->com_name);
     }
     $vcard->addJobtitle($about->profession);
     $vcard->addEmail($contact->email);
     $vcard->addPhoneNumber($contact->phone_no, 'WORK');
     $vcard->addAddress($contact->address, 'WORK');
    $vcard->addPhoneNumber($contact->whatsapp, 'WORK');

    return $vcard->download();
    }



    public function viewVcard($user_id,$theme_id)
    {
        $setting_data = Setting::get()->toArray();
        $auth_id =Auth::user()->id;
        $about = VCardAbout::where('user_id',$auth_id)->orderBy('created_at', 'DESC')->first();
        $social = VCardSocialLink::where('user_id',$auth_id)->orderBy('created_at', 'DESC')->first();
        $company = VCardComDetail::where('user_id',$auth_id)->orderBy('created_at', 'DESC')->first();
        $contact = VCardContactDetail::where('user_id',$auth_id)->orderBy('created_at', 'DESC')->first();
        $shareLink = VCardSelectedTheme::select('vcard_url_id')->where('user_id',$auth_id)->first();
        $SocialLink = json_decode($social->social_link,true);

        // return view('viewVcard',compact('about','SocialLink','shareLink','company','contact'));
        return view('vcard-themes.'.$theme_id,compact('about','SocialLink','shareLink','company','contact','setting_data'));
    }


    public function vcard(Request $request, $user_name, $url_id)
    {
        $url_name= $request->user_name;
        $url_ID= $request->url_id;
        $url_id = explode("&", $url_ID);

        $auth_id =$url_id[1];

        $current_date = date('Y-m-d');
        $setting_data = Setting::get()->toArray();
        $diff = abs(strtotime(Auth::user()->created_at) - strtotime($current_date));
        $years = (int)floor($diff / (365*60*60*24));
        $months = (int)floor(($diff - $years * 365*60*60*24) / (30*60*60*24));
        $days = (int)floor(($diff - $years * 365*60*60*24 - $months*30*60*60*24)/ (60*60*24));
        $remaining_days = $setting_data[19]['value'] - $days;

        $transaction = VCardTransaction::where('user_id',$auth_id)->orderby('created_at','desc')->first();
        try {
            if ($transaction->status != 'TXN_SUCCESS' && $remaining_days <= 0) {
                return redirect('expireVcard');
            }
        }catch (\Exception $e){
            //error..
    }



         $about = VCardAbout::where('user_id',$auth_id)->orderBy('created_at', 'DESC')->first();
         $social = VCardSocialLink::where('user_id',$auth_id)->orderBy('created_at', 'DESC')->first();
         $company = VCardComDetail::where('user_id',$auth_id)->orderBy('created_at', 'DESC')->first();
         $contact = VCardContactDetail::where('user_id',$auth_id)->orderBy('created_at', 'DESC')->first();
         $SocialLink = json_decode($social->social_link,true);
         $shareLink = VCardSelectedTheme::select('vcard_url_id', 'theme_id')->where('user_id',$auth_id)->first();

        return view('vcard-themes.'.$shareLink->theme_id, compact('about', 'SocialLink','shareLink', 'company', 'contact','setting_data'));
    }

public function expireVcard(Request $request){
        return view('expireVcard');
}

    public function ChooseTheme()
    {
        $selectedTheme =  VCardSelectedTheme::where('user_id',Auth::user()->id)->first();
        if($selectedTheme)
        {
            $is_exist = 'yes';
        }
        else
        {
            $is_exist = 'no';
        }
        $setting_data = Setting::get()->toArray();
        $theme = VCardTheme::all();
        return view('theme',compact('theme','setting_data','is_exist'));
    }

    public function payment(Request $request)
    { 
        $discount = 0;
        $order_id=rand();
       
        if(session()->has('coupon') && session()->get('coupon')!=null) {
            $couponID = session()->get('coupon');
            $coupon = Coupon::where('coupon_id',$couponID)->first();
            $discount = $coupon->price_discount;
        }


        $payment_method = Setting::where('key','payment_method')->first()->value;
        $setting_method= Setting::get()->toArray();
        $validator = Validator::make($request->all(),[
            'theme_id' =>'required',
            'payment_status'=>'required',
        ],[
                'theme_id.required'=>'Please select the theme!',]

        );

        if ($validator->fails()) {
            return redirect()->back()
                ->withErrors($validator)
                ->withInput();
        }

        $about = VCardAbout::where('user_id', Auth::user()->id)->first();
        $userContact  =  VCardContactDetail::where('user_id',Auth::user()->id)->first();
        if($request->is_theme_exist == 'yes' || $request->payment_status == 'after-trial')
        {
            $selectedTheme =  VCardSelectedTheme::where('user_id',Auth::user()->id)->first();
        }
        else
        {
            $selectedTheme = new VCardSelectedTheme();
        }
         $selectedTheme->theme_id = $request->theme_id;
         $selectedTheme->user_id = Auth::user()->id;

         $namein_url = str_replace(' ', '-',$about->fname.' '.$about->lname);
         $selectedTheme->vcard_url_id = $namein_url.'/'.rand().'&'.Auth::user()->id;

         if($request->payment_status == 'payment_later'){
             $selectedTheme->payment_status = '0';
             $selectedTheme->save();
        }else{
                $selectedTheme->payment_status = '0'; //pending
                $selectedTheme->save();

                if($payment_method == 'instamojo')
                {
                  /*$authType = "app";
                  $api = \Instamojo\Instamojo::init($authType,[
                      "client_id" =>  config('services.instamojo.api_key'),
                      "client_secret" => config('services.instamojo.auth_token'),

                  ],false);*/
 
                  if($discount)
                     $final_amonut = ( 100 - $discount);
                  else
                     $final_amonut = 100;


                    $api = new \Instamojo\Instamojo(
                      config('services.instamojo.api_key'),
                      config('services.instamojo.auth_token'),
                      config('services.instamojo.url')
                    );
                    try
                    {
                        $response = $api->paymentRequestCreate(array(
                          "purpose" => "Generate Vcard",
                          "amount" => $final_amonut,
                          "send_email" => true,
                          "email" => $userContact->email,
                          "redirect_url" => url('payment/status'.'/'.Auth::user()->id)
                        ));
                        
                        header('Location: ' . $response['longurl']);
                        exit();
                    }
                    catch (Exception $e)
                    {
                        print('Error: ' . $e->getMessage());
                    }
                }else if($payment_method == 'paypal'){
                    $data = [];
                    $data['items'] = [
                                        [
                                            'name' => Auth::user()->name,
                                            'price' =>(1-$discount),
                                            'order' => $order_id,
                                        ]
                                    ];
                    $data['invoice_id'] = $order_id;
                    $data['invoice_description'] = $order_id;
                    $data['return_url'] = url('payment/status'.'/'.Auth::user()->id);
                    $data['cancel_url'] = route('payment.cancel');
                    $data['notify_url'] = route('payment.notify');
                    $data['total'] = (1-$discount);
                    $provider = new ExpressCheckout;
                  
                    $response = $provider->setExpressCheckout($data);
              
                    $response = $provider->setExpressCheckout($data, true);

                 
                    return redirect($response['paypal_link']);

                }
                else
                {
                    $payment = PaytmWallet::with('receive');
                    $payment->prepare([
                    'order' => rand(),
                    'user' => Auth::user()->id ,
                    'mobile_number' => $userContact->phone_no,
                    'email' => $userContact->email,
                    'amount' => (1-$discount),
                    // 'callback_url' => 'https://lab3.invoidea.in/onlinevcards/createvcard/public/payment/status'
                    'callback_url' => url('payment/status'.'/'.Auth::user()->id)
                    ]);
                    return $payment->receive();
                }
         }
        $details = [
            'greeting' => 'Hi '. Auth::user()->name,
            'body' => 'Your Vcard has been generated successfully '.$selectedTheme->vcard_url_id,
            'thanks' => 'Thank you ',
            'logo'=>$setting_method['4']['value']
        ];
      $mail = Mail::to(Auth::user()->email)->send(new VcardMail($details));

        return redirect('dashboard')->with('success','Vcard created successfully!!');
    }

    public function paymentCallback(Request $request, $user_id)
    {

        if(session()->has('coupon') && session()->get('coupon')!=null){
            $couponId = session()->get('coupon');
        }else{
            $couponId=null;
        }
        $user_details = User::where('id',$user_id)->first();
        $vcardTransaction = new VCardTransaction();
        $payment_method = Setting::where('key','payment_method')->first()->value;
        $setting_method = Setting::get()->toArray();
        if($payment_method == 'instamojo')
        {
            $api = new \Instamojo\Instamojo(
            config('services.instamojo.api_key'),
            config('services.instamojo.auth_token'),
            config('services.instamojo.url')
            );
            $response = $api->paymentRequestStatus(request('payment_request_id'));
            if(!isset($response['payments'][0]['status']))
            {
                return redirect('success')->with('warning','Your transaction has been failed!');
            }
            elseif(isset($response['payments'][0]['status']) && $response['payments'][0]['status'] != 'Credit')
            {
                $vcardTransaction->name = $response['payments'][0]['instrument_type'];
                $vcardTransaction->phone = $response['payments'][0]['buyer_phone'];
                $vcardTransaction->amount = $response['payments'][0]['amount'];
                $vcardTransaction->status = 'TXN_FAIED';
                $vcardTransaction->order_id = $response['id'];
                $vcardTransaction->transaction_id = $response['payments'][0]['payment_id'];
                $vcardTransaction->user_id = $user_id;
                $vcardTransaction->coupon_id = $couponId;//default
                $vcardTransaction->created_at = $response['payments'][0]['created_at'];
                $vcardTransaction->save();
                $details = [
                    'greeting' => 'Hi '.$user_details->name,
                    'body' => 'your transaction status :  TXN_FAIED',
                    'thanks' => 'Thank you ',
                ];
                $mail = Mail::to(Auth::user()->email)->send(new PaymentMail($details));
                return redirect('success')->with('warning','Your transaction has been failed!');
            }
            elseif (isset($response['payments'][0]['status']) && $response['payments'][0]['status'] == 'Credit')
            {
                $transactionId = $response['payments'][0]['payment_id'];
                $phone = $response['payments'][0]['buyer_phone'];
                $amount = $response['payments'][0]['amount'];
                $discount = 0;
                if(session()->has('coupon') && session()->get('coupon')!=null) {
                    $couponID = session()->get('coupon');
                    $coupon = Coupon::where('coupon_id',$couponID)->first();
                    $discount = $coupon->price_discount;
                }

                $totalAmount = $amount+$discount;
                $vcardTransaction->name = $response['payments'][0]['instrument_type'];
                $vcardTransaction->phone = $phone;
                $vcardTransaction->amount = $amount;
                $vcardTransaction->status = 'TXN_SUCCESS';
                $vcardTransaction->order_id = $response['id'];
                $vcardTransaction->transaction_id = $transactionId;
                $vcardTransaction->user_id = $user_id;
                $vcardTransaction->coupon_id = $couponId;//default
                $vcardTransaction->created_at = $response['payments'][0]['created_at'];
                $vcardTransaction->save();
                $details = [
                'greeting' => 'Hi '.$user_details->name,
                'body' => 'Your transaction status :  SUCCESS',
                'thanks' => 'Thank you ',
                    'transactionId'=>$transactionId,
                    'logo'=>$setting_method['4']['value'],
            ];

                $pdf = PDF::loadView('pdf.index',compact('user_details','couponId','transactionId','discount','totalAmount','amount','phone','setting_method'));
                $pdf->save(storage_path('invoice.pdf'));
                $meesage = new PaymentMail($details);
                $meesage->attachData($pdf->output(),'invoice.pdf');
                $mail = Mail::to(Auth::user()->email)->send($meesage);
                VCardSelectedTheme::where('user_id', $user_details->id)->update(['payment_status' => '1']);
                return redirect('success')->with('success','Your transaction has been successfully done!');
            }
        }

        else if($payment_method == 'paypal'){
            $provider = new ExpressCheckout;
        
        $response = $provider->getExpressCheckoutDetails($request->token);
           
            $vcardTransaction->phone = $user_details->phone;
            $vcardTransaction->amount = $response['AMT'];
            $vcardTransaction->status = $response['ACK'];
            $vcardTransaction->order_id = $response['INVNUM'];
            $vcardTransaction->transaction_id = $response['TOKEN'];
            $vcardTransaction->user_id = $user_details->id;
            $vcardTransaction->coupon_id = $couponId;//default
            $vcardTransaction->created_at = $response['TIMESTAMP'];
            $vcardTransaction->save();
            $details = [
                'greeting' => 'Hi '.$user_details->name,
                'body' => 'Your transaction status :  SUCCESS',
                'thanks' => 'Thank you ',
            ];
            if (in_array(strtoupper($response['ACK']), ['SUCCESS', 'SUCCESSWITHWARNING'])) {
           
           return redirect()->back()->with('success', 'Payment Successfully Credited.');
        }else{
            return redirect()->back()->with('error', 'Payment Successfully Failed.');
        }
        }
        else
        {
            $transaction = PaytmWallet::with('receive');
            $response = $transaction->response();
            $vcardTransaction->name = $response['BANKNAME'];
            $vcardTransaction->phone = $user_details->phone;
            $vcardTransaction->amount = $response['TXNAMOUNT'];
            $vcardTransaction->status = $response['STATUS'];
            $vcardTransaction->order_id = $response['ORDERID'];
            $vcardTransaction->transaction_id = $response['TXNID'];
            $vcardTransaction->user_id = $user_details->id;
            $vcardTransaction->coupon_id = $couponId;//default
            $vcardTransaction->created_at = $response['TXNDATE'];
            $vcardTransaction->save();
            $details = [
                'greeting' => 'Hi '.$user_details->name,
                'body' => 'your transaction status :  '.$response['STATUS'],
                'thanks' => 'Thank you ',
            ];

            Auth::guard('web')->attempt(['email' => $user_details->email,'password' => $user_details->password]);
            $mail = Mail::to(Auth::user()->email)->send(new PaymentMail($details));
            if($transaction->isSuccessful())
            {
                VCardSelectedTheme::where('user_id', $user_details->id)->update(['payment_status' => '1']);
                return redirect('success')->with('success','Your transaction has been successfully done!');
            }
            else if($transaction->isFailed())
            {
                return redirect('success')->with('warning','Your transaction has been failed!');
            }
        }
    }

    public function viewSuccess()
    {
        $setting_data = Setting::get()->toArray();
         $view = VCardSelectedTheme::where('user_id',Auth::user()->id)->first();
         $transaction = VCardTransaction::where('user_id',Auth::user()->id)->orderBy('created_at', 'DESC')->first();
        return view('viewSuccess',compact('view','transaction','setting_data'));
    }

    public function profile()
    {
        $setting_data = Setting::get()->toArray();
        $current_date = date('Y-m-d');
        $auth_id =Auth::user()->id;
        $about = VCardAbout::where('user_id',$auth_id)->orderBy('created_at', 'DESC')->first();
        if(!$about)
        {
            return view('profile',compact('about','setting_data'));
        }
        $social = VCardSocialLink::where('user_id',$auth_id)->get()->toArray();
        foreach ($social as $key => $value)
        {
            $social_array[] = json_decode($value['social_link'],true);
        }
        foreach ($social_array as $key => $value1)
        {
            foreach ($value1 as $key3 => $value2)
            {
                $social_link_array[$key3] = $value2;
            }
        }
        $company = VCardComDetail::where('user_id',$auth_id)->first();
        $contact = VCardContactDetail::where('user_id',$auth_id)->first();
        $transaction = VCardTransaction::where('user_id',Auth::user()->id)->orderBy('created_at', 'DESC')->first();
        // dd($contact);
        $shareLink = VCardSelectedTheme::select('vcard_url_id','payment_status','theme_id')->where('user_id',$auth_id)->first();
        $social_links =  $social_link_array;
        $diff = abs(strtotime(Auth::user()->created_at) - strtotime($current_date));
        $years = (int)floor($diff / (365*60*60*24));
        $months = (int)floor(($diff - $years * 365*60*60*24) / (30*60*60*24));
        $days = (int)floor(($diff - $years * 365*60*60*24 - $months*30*60*60*24)/ (60*60*24));
        $remaining_days = $setting_data[19]['value'] - $days;

        return view('profile',compact('about','social_links','shareLink','company','contact','remaining_days','setting_data','transaction'));
    }

    public function updateProfile(Request $request)
    {
        $validator = Validator::make($request->all(),[
            'fb_url' => 'nullable|regex:/^(https?:\/\/)?([\da-z\.-]+)\.([a-z\.]{2,6})([\/\w \.-]*)*\/?$/',
            'comp_yt_link' => 'nullable|regex:/^(https?:\/\/)?([\da-z\.-]+)\.([a-z\.]{2,6})([\/\w \.-]*)*\/?$/',
            'address_map_link' => 'nullable|regex:/^(https?:\/\/)?([\da-z\.-]+)\.([a-z\.]{2,6})([\/\w \.-]*)*\/?$/',
            //'social_link' => 'regex:/^(https?:\/\/)?([\da-z\.-]+)\.([a-z\.]{2,6})([\/\w \.-]*)*\/?$/',
           // 'skype_id' => 'regex:/^(https?:\/\/)?([\da-z\.-]+)\.([a-z\.]{2,6})([\/\w \.-]*)*\/?$/',
            'firstname' =>'required',
            'lastname'=>'required',
            'profession'=>'required',
            // 'profile_img'=>'required',
            // 'company_logo'=>'required',
        ],[
            'fname.required'=>'First Name Field is required!',
            'lastname.required'=>'Last Name Field is required!',
            'profession.required'=>'Profession  Field is required!',
            'profile_img.required'=>'Profile image Field is required!',
            'company_logo.required'=>'Company logo Field is required!',

        ]);

        if ($validator->fails())
        {
            return redirect()->back()->withErrors($validator)->withInput();
        }

        $about = VCardAbout::where('user_id',Auth::user()->id)->first();
        if($about == null)
        {
            $about = new VCardAbout();
        }
        $about->fname = $request->firstname;
        $about->lname = $request->lastname;
        $about->profession = $request->profession;
        $about->about_me = $request->about_me;
        $about->user_id = Auth::user()->id;
        $about->save();

        $contact = VCardContactDetail::where('user_id',Auth::user()->id)->first();
        if($contact == null)
        {
            $contact = new VCardContactDetail();
        }
            $contact->phone_no = $request->phone;
            $contact->email = $request->email;
            $contact->whatsapp = $request->whatsapp;
            $contact->address = $request->address;
            $contact->skype_id = $request->skype_id;
            $contact->fb_messenger_id = $request->fb_url;
            $contact->user_id = Auth::user()->id;
            $contact->save();

            $company = VCardComDetail::where('user_id',Auth::user()->id)->first();
            if($company == null)
            {
                $company = new VCardComDetail();
            }

             $company->com_name = $request->company_name;
             $company->com_tagline = $request->company_title;
             $company->about_com = $request->about_company;
             $company->com_youtube_link = $request->comp_yt_link;
             $company->com_map_link = $request->address_map_link;
             $company->user_id = Auth::user()->id;
             $company->save();

            if ($request->hasFile('company_logo'))
            {
                $fileLogo = "logo" . time() . '.' . request()->company_logo->getClientOriginalExtension();
                $request->company_logo->move(public_path().'/users/companylogo', $fileLogo);
                $company->com_logo = $fileLogo;
                $company->save();
            }

         VCardSocialLink::where('user_id',Auth::user()->id)->delete();
         $social = new VCardSocialLink();
         $social->social_link_name = json_encode($request->siteSocial);
         $social->social_link = json_encode(array_combine($request->siteSocial,$request->social_link));
         $social->user_id = Auth::user()->id;
         $social->save();


        if($request->hasFile('profile_img'))
        {
            $fileName = "profileImg-" . time() . '.' . request()->profile_img->getClientOriginalExtension();
            $request->profile_img->move(public_path().'/users/profileimg/', $fileName);
            $about->profile_img = $fileName;
            $about->save();
        }

        if(isset($request->payment))
        {
         $userContact  =  VCardContactDetail::where('user_id',Auth::user()->id)->first();
         $selectedTheme = VCardSelectedTheme::where('user_id',Auth::user()->id)->first();
         $selectedTheme->theme_id = $selectedTheme->theme_id;
         $selectedTheme->user_id = Auth::user()->id;

         $about = VCardAbout::where('user_id', Auth::user()->id)->first();

         $namein_url = str_replace(' ', '-',$about->fname.' '.$about->lname);
         $selectedTheme->vcard_url_id = $namein_url.'/'.rand().'&'.Auth::user()->id;

            if($request->payment_status == 'payment_later')
            {
                 $selectedTheme->payment_status = '0';
                 $selectedTheme->save();
            }
            else
            {
                 $selectedTheme->payment_status = '0'; //pending
                 $selectedTheme->save();
                if($payment_method == 'instamojo')
                {
                    $api = new \Instamojo\Instamojo(
                    config('services.instamojo.api_key'),
                    config('services.instamojo.auth_token'),
                    config('services.instamojo.url')
                    );
                    try
                    {
                        $response = $api->paymentRequestCreate(array(
                        "purpose" => "Generate Vcard",
                        "amount" => 10,
                        "buyer_name" => Auth::user()->name,
                        "send_email" => false,
                        "email" => $userContact->email,
                        "phone" => $userContact->phone_no,
                        "redirect_url" => url('payment/status'.'/'.Auth::user()->id)
                        ));
                        header('Location: ' . $response['longurl']);
                        exit();
                    }
                    catch (Exception $e)
                    {
                        print('Error: ' . $e->getMessage());
                    }
                }
                else
                {
                    $payment = PaytmWallet::with('receive');
                    $payment->prepare([
                    'order' => rand(),
                    'user' =>  Auth::user()->id ,
                    'mobile_number' => $userContact->phone_no,
                    'email' => $userContact->email,
                    'amount' => 1,
                    // 'callback_url' => 'https://lab3.invoidea.in/onlinevcards/createvcard/public/payment/status'
                    'callback_url' => url('payment/status'.'/'.Auth::user()->id)
                    ]);
                    return $payment->receive();
                }
            }

            $details = [
                'greeting' => 'Hi '. Auth::user()->name,
                'body' => 'Your Vcard has been generated successfully '.$selectedTheme->vcard_url_id,
                'thanks' => 'Thank you ',
            ];

            $mail = Mail::to(Auth::user()->email)->send(new WelcomeMail($details));
            return redirect('success');
        }
        // return redirect('profile');
        return redirect('create-vcard/theme');
    }

   public function dashboard()
    {
        $current_date = date('Y-m-d');
       
        $setting_data = Setting::get()->toArray();
        
        
        $diff = abs(strtotime(Auth::user()->created_at) - strtotime($current_date));
        
        $years = (int)floor($diff / (365*60*60*24));
        $months = (int)floor(($diff - $years * 365*60*60*24) / (30*60*60*24));
        $days = (int)floor(($diff - $years * 365*60*60*24 - $months*30*60*60*24)/ (60*60*24));
        $remaining_days = $setting_data[19]['value'] - $days;
        if($remaining_days <0 ) $remaining_days = 0;
        $auth_id =Auth::user()->id;
        $about = VCardAbout::where('user_id',$auth_id)->orderBy('created_at', 'DESC')->first();
        if(!$about)
        {
            return view('dashboard',compact('about','setting_data','remaining_days'));
        }
        $social = VCardSocialLink::where('user_id',$auth_id)->get()->toArray();
        foreach ($social as $key => $value)
        {
            $social_array[] = json_decode($value['social_link'],true);
        }
        foreach ($social_array as $key => $value1)
        {
            foreach ($value1 as $key3 => $value2)
            {
                $social_link_array[$key3] = $value2;
            }
        }
        $company = VCardComDetail::where('user_id',$auth_id)->first();
        $contact = VCardContactDetail::where('user_id',$auth_id)->first();
        $transaction = VCardTransaction::where('user_id',Auth::user()->id)->orderBy('created_at', 'DESC')->first();
       
        $shareLink = VCardSelectedTheme::select('vcard_url_id','payment_status','theme_id')->where('user_id',$auth_id)->first();
        $social_links =  $social_link_array;

        $coupon = Coupon::where('status','1')->orderby('created_at', 'DESC')->first();

        return view('dashboard',compact('about','social_links','shareLink','company','contact','remaining_days','setting_data','transaction','coupon'));
    }

    public function validateCoupon(Request $request){

        $coupon = Coupon::where('coupon_code',$request->coupon_code)->where('status','1')->first();

        $TotalUsedCoupon = VCardTransaction::where('coupon_id',$coupon->coupon_id)->count();
        if($coupon->no_of_use<=$TotalUsedCoupon || $coupon->expire_date<date("Y-m-d")){
            session()->put('coupon',null);
            return false;
        }else{
            session()->put('coupon',$coupon->coupon_id);
            //$request->session()->put('coupon',$coupon->coupon_id);
            return true;
        }
    }
}


