<?php

use Illuminate\Support\Facades\Route;
use App\Models\Setting;
use App\Models\PlanTransaction;
use App\Seller;
/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/
Route::get('/', function () {
    $setting_data = Setting::get()->toArray();
    return view('index',compact('setting_data'));
});

Route::post('contact-us', 'CustomerController@contactUs');

Route::get('/create-vcard', function () {
    $setting_data = Setting::get()->toArray();
     
        return view('home',compact('setting_data'));
    })->middleware(['auth','vcard']);

Route::get('/reseller/login', function () {
        return view('reseller.login');
    });

Route::post('/sellerLogin', ['as'=>'sellerLogin','uses'=>'SellerController@sellerLogin']);

Route::get('/reseller/register', function () {
        return view('reseller.register');
    });

Route::post('/sellerRegister','SellerController@sellerRegister');  

Route::group(['middleware' => ['auth:seller-web']], function() {

Route::get('/reseller/dashboard','SellerController@dashboard');
Route::post('/storePlan','SellerController@storePlan');
/*Route::post('/payment_store','SellerController@payment_store');*/
Route::post('/payment_store', 'SellerController@payment')->name('payment_store');
Route::any('payments/status/{user_id}', 'SellerController@paymentCallback');
/*Route::post('payments/status', 'SellerController@paymentCallback');*/
Route::get('/reseller/transaction', 'SellerController@transaction');
Route::get('/reseller/active_plan', 'SellerController@active_plan');
Route::get('/web_setting','SellerController@web_setting');
Route::get('/reseller/profile', 'SellerController@profile');
Route::post('/update/profile', 'SellerController@updateProfile');
Route::post('/save/web_setting','SellerController@saveSetting');
Route::get('cancel', 'SellerController@cancel')->name('payment.cancel');
Route::get('payment/success', 'SellerController@success')->name('payment.success');
Route::any('payment/notify', 'SellerController@notify')->name('payment.notify');
Route::post('/payment-complete','SellerController@complete')->name('payment_complete');
Route::post('stripe', 'SellerController@stripePost')->name('stripe.post');
Route::get('/reseller/stripe','SellerController@stripe_form');
Route::get('/reseller/logout','SellerController@logout');
});

Route::group(['middleware'=>'auth'],function(){
   
    Route::get('profile','ProfileController@profile')->name('profile');
    Route::get('dashboard','ProfileController@dashboard')->name('dashboard');

    Route::get('/products/step-one', 'Dashboard\VCardController@createStepOne')->name('products.step-one');
    Route::post('/products/step-one', 'Dashboard\VCardController@postCreateStepOne');

    Route::get('/products/step-two', 'Dashboard\VCardController@createStepTwo')->name('products.step-two');
    Route::post('/products/step-two', 'Dashboard\VCardController@postCreateStepTwo');

    Route::post('/products/remove-image', 'Dashboard\VCardController@removeImage');

    Route::get('/products/step-three', 'Dashboard\VCardController@createStepThree');
    Route::post('/products/store', 'Dashboard\VCardController@store')->name('products.store');

    Route::get('/products/virtual-card', 'Dashboard\VCardController@cardGenerate');

    Route::get('products/card_get', 'ProfileController@getCard');
 
    Route::post('profile/update-profile', 'ProfileController@storeData')->name('products.storedata');
    Route::post('update-profile', 'ProfileController@updateProfile')->name('update.profile');

    Route::post('profile/payment-method', 'ProfileController@payment')->name('payments');
    Route::get('create-vcard/theme', 'ProfileController@ChooseTheme');
    Route::get('success', 'ProfileController@viewSuccess')->name('view-success');
    Route::get('view-vcard/','ProfileController@viewVcard')->name('view-vcard');
    Route::get('profile/preview-vcard/','ProfileController@viewVcard')->name('preview-vcard');
    Route::get('vcardpreview/{user_id}/{theme_id}','ProfileController@viewVcard');
    Route::get('validate-coupon','ProfileController@validateCoupon');

    
    Route::get('products/payment-register', 'CustomerController@register')->name('products.payment-register');
    Route::post('products/download/vcard', 'ProfileController@downloadvCard')->name('download');
    Route::post('payment', 'CustomerController@payment');

});

Route::any('payment/status/{user_id}', 'ProfileController@paymentCallback');
Route::get('download-vcard/{user_id}', 'ProfileController@downloadVCard')->name('download-vcard');
Route::get('vcard/{user_name}/{url_id}','ProfileController@vcard')->name('sharevcard');
Route::get('expireVcard','ProfileController@expireVcard')->name('expireVcard');

/** Auth login and Registration **/
Auth::routes();
Route::get('/home', 'HomeController@index')->name('home');

# Admin Routes
Route::get('admin', function () {
    return view('admin.login');
});
Route::post('admin-login','Admin\AuthController@login');

Route::group(['prefix' => 'admin','middleware' => ['auth:admin-web']], function() {

    Route::get('logout','Admin\AuthController@logout');
    
    Route::get('dashboard','Admin\DashboardController@index');
    Route::get('listing/{type}',function($type){

        $setting_data = Setting::get()->toArray();
        if($type == 'transaction-history') {
            return view('admin.transaction-history',compact('type','setting_data'));
        } elseif($type == 'registered-users') {
          return view('admin.registered-users',compact('type','setting_data'));
        } elseif($type=='vcard-users'){
            return view('admin.vcard-users',compact('type','setting_data'));
        }elseif($type == 're-seller-users'){
         
           $plan_data=PlanTransaction::leftJoin('resellers','resellers.id','=','plan_member_transaction.reseller_id')
                   ->leftJoin('plans','plans.id','=','plan_member_transaction.plan_id')->get();
            return view('admin.re-seller-users',compact('type','setting_data','plan_data'));
        }else{
            return view('admin.coupon-list',compact('type','setting_data'));
        }
    });
    Route::get('list','Admin\DashboardController@show_plan');
    Route::get('listing-data','Admin\DashboardController@listing');
    Route::get('setting/{type}','Admin\DashboardController@setting');
    Route::post('update/{type}','Admin\DashboardController@saveSetting'); 
    Route::get('admin/plan_data/{id}','Admin\DashboardController@plan_data');
    
    Route::post('save-payment-setting','Admin\DashboardController@savePaymentSetting'); 
    Route::post('export/{type}','Admin\DashboardController@export');
    Route::post('send-email','Admin\DashboardController@sendMail');
    Route::post('send-sms','Admin\DashboardController@sendSMS');
    Route::post('update-payment-method','Admin\DashboardController@updatePaymentMethod');

    Route::get('coupons','Admin\CouponController@index')->name('coupons');
    Route::get('coupons/create','Admin\CouponController@create');
    Route::post('save-coupon','Admin\CouponController@create')->name('save_coupon');
    Route::post('/editPlan','Admin\DashboardController@editPlan');
    Route::post('/updatePlan','Admin\DashboardController@updatePlan');
});



//New Site

Route::get('/1', function () {
    $setting_data = Setting::get()->toArray();
    return view('new_site.index',compact('setting_data'));
});

Route::get('/create-vcard/1', function () {
    $setting_data = Setting::get()->toArray();
        return view('new_site.home',compact('setting_data'));
    })->middleware(['auth','vcard']);

Route::get('/register/1', 'New_site\Auth\RegisterController@showRegistrationForm');

Route::get('/login/1', 'New_site\Auth\LoginController@showLoginForm');

Route::group(['middleware'=>'auth'],function(){

    Route::get('dashboard/1','New_site\ProfileController@dashboard');
    Route::get('profile/1','New_site\ProfileController@profile')->name('user_profile');
    Route::post('update_profile', 'New_site\ProfileController@updateProfile')->name('profile.update');
    Route::get('create-vcard/theme/1', 'New_site\ProfileController@ChooseTheme');
    Route::get('vcardpreview/{user_id}/{theme_id}/1','New_site\ProfileController@viewVcard');
    Route::post('profile/payment-methods', 'New_site\ProfileController@payment');
    Route::get('success/1', 'New_site\ProfileController@viewSuccess')->name('view_success');
    Route::get('view-vcard/1','New_site\ProfileController@viewVcard')->name('view_vcard');
    Route::get('profile/preview-vcard/1/','New_site\ProfileController@viewVcard')->name('preview_vcard');
});

Route::get('/home/1', 'New_site\HomeController@index')->name('home');




# ReSeller Admin Routes
Route::get('admin/1', function () {
    return view('new_site.admin.login');
});

Route::post('admin_login','New_site\Admin\AuthController@login');

Route::group(['prefix' => 'admin','middleware' => ['auth:admin-web']], function() {

    Route::get('logout/1','New_site\Admin\AuthController@logout');
    
    Route::get('dashboard/1','New_site\Admin\DashboardController@index');
    Route::get('listing/{type}/1',function($type){

        $setting_data = Setting::get()->toArray();
        if($type == 'transaction-history') {
            return view('new_site.admin.transaction-history',compact('type','setting_data'));
        } elseif($type == 'registered-users') {
          return view('new_site.admin.registered-users',compact('type','setting_data'));
        } elseif($type=='vcard-users'){
            return view('new_site.admin.vcard-users',compact('type','setting_data'));
        }else{
            return view('new_site.admin.coupon-list',compact('type','setting_data'));
        }
    }); 
    Route::get('list/1','New_site\Admin\DashboardController@show_plan');
    Route::get('listing-data/1','New_site\Admin\DashboardController@listing');
    Route::get('setting/{type}/1','New_site\Admin\DashboardController@setting');
    Route::post('new_site/update/{type}','New_site\Admin\DashboardController@saveSetting');
    Route::get('admin/plan_data/{id}/1','New_site\Admin\DashboardController@plan_data');
    
    Route::post('new_site/save-payment-setting','New_site\Admin\DashboardController@savePaymentSetting');
    Route::post('new_site/export/{type}','New_site\Admin\DashboardController@export');
    Route::post('new_site/send-email','New_site\Admin\DashboardController@sendMail');
    Route::post('new_site/send-sms','New_site\Admin\DashboardController@sendSMS');
    Route::post('new_site/update-payment-method','New_site\Admin\DashboardController@updatePaymentMethod');

    Route::get('coupons/1','New_site\Admin\CouponController@couponindex')->name('coupon');
    Route::get('coupons/create/1','New_site\Admin\CouponController@create');
    Route::post('new_site/save-coupon','New_site\Admin\CouponController@create')->name('save_coupons');
});
   Route::post('/new_site/storePlan','SellerController@storePlan');